@@ -101,7 +101,7 @@ ISOFormat <- R6Class("ISOFormat",
       
       #setSpecification
       setSpecification = function(specification, locales = NULL){
-        self$specification <- as.character(specification)
+        self$specification <- specification
         if(!is.null(locales)){
           self$specification <- self$createLocalisedProperty(specification, locales)
         }
@@ -128,4 +128,26 @@ ISOFormat <- R6Class("ISOFormat",
         return(self$delListElement("FormatDistributor", distributor))
       }
     )                        
-)
\ No newline at end of file
+)
+
+ISOFormat$buildFrom = function(mimetype){
+  
+  mimetypes = getIANAMimeTypes()
+  mime = mimetypes[mimetypes$name == mimetype,]
+  
+  format = ISOFormat$new()
+  format$setVersion(NA)
+  if(!is.null(mime)){
+    if(nrow(mime)>0){
+      format$setName(ISOAnchor$new(name = mimetype, href = mime$uri))
+      if(!is.na(mime$rfc)){
+        format$setSpecification(ISOAnchor$new(name = toupper(mime$rfc), href = mime$rfc_uri))
+      }
+    }else{
+      format$setName(mimetype)
+    }
+  }else{
+    format$setName(mimetype)
+  }
+  return(format)
+}
\ No newline at end of file
