@@ -7,13 +7,21 @@
 #' @return Object of \code{\link{R6Class}} for modelling an ISO Telephone
 #' @format \code{\link{R6Class}} object.
 #'
-#' @field voice
-#' @field facsimile
+#' @field voice [\code{\link{character}}] phone number
+#' @field facsimile [\code{\link{character}}] facsimile number
 #'
 #' @section Methods:
 #' \describe{
 #'  \item{\code{new(xml,value)}}{
-#'    This method is used to instantiate an ISOTelephone
+#'    This method is used to instantiate an \code{\link{ISOTelephone}}
+#'  }
+#'  \item{\code{setVoice(voice, locales)}}{
+#'    Set voice phone number. Locale numbers can be specified as \code{list}
+#'    with the \code{locales} argument.
+#'  }
+#'  \item{\code{setFacsimile(voice, locales)}}{
+#'    Set facsimile phone number. Locale numbers can be specified as \code{list}
+#'    with the \code{locales} argument.
 #'  }
 #' }
 #' 
@@ -42,15 +50,21 @@ ISOTelephone <- R6Class("ISOTelephone",
      },
      
      #setVoice
-     setVoice = function(voice){
+     setVoice = function(voice, locales = NULL){
        if(!is(voice,"character")) voice <- as.character(voice)
        self$voice = voice
+       if(!is.null(locales)){
+         self$voice <- self$createLocalisedProperty(voice, locales)
+       }
      },
      
      #setFacsimile
-     setFacsimile = function(facsimile){
+     setFacsimile = function(facsimile, locales = NULL){
        if(!is(facsimile,"character")) facsimile <- as.character(facsimile)
        self$facsimile = facsimile
+       if(!is.null(locales)){
+         self$facsimile <- self$createLocalisedProperty(facsimile, locales)
+       }
      }
    )                        
 )
\ No newline at end of file
